@@ -7,6 +7,7 @@ OC.L10N.register(
     "Token expired or app not enabled! Reload the page!" : "Valtuutus vanheni tai sovellus ei käytössä. Lataa sivu uudelleen.",
     "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Sisäinen palvelinvirhe! Tarkista tiedosto data/nextcloud.log saadaksesi lisätietoja!",
     "Request failed, Nextcloud is in currently in maintenance mode!" : "Pyyntö epäonnistui, Nextcloud on parhaillaan huoltotilassa!",
+    "Can not add feed: Unable to parse feed" : "Syötettä ei voi lisätä: syötteen jäsentäminen epäonnistui",
     "Can not add feed: Exists already" : "Syötettä ei voi lisätä: se on jo olemassa",
     "Articles without feed" : "Vailla syötettä olevat artikkelit",
     "Can not add folder: Exists already" : "Kansiota ei voi lisätä: se on jo olemassa",
@@ -16,8 +17,10 @@ OC.L10N.register(
     "Purge interval" : "Hävitysväli",
     "Maximum read count per feed" : "Syötekohtaisten lukukertojen enimmäismäärä",
     "Maximum redirects" : "Uudelleenohjausten enimmäismäärä",
-    "Maximum feed page size" : "Syötteen sivun enimmäiskoko",
+    "How many redirects the feed fetcher should follow." : "Kuinka montaa uudelleenohjausta syötteen noutajan tulisi seurata.",
     "Feed fetcher timeout" : "Syötteen hakemisen aikakatkaisu",
+    "For more information check the wiki." : "Lue lisätietoja wikistä.",
+    "Update interval" : "Päivitysväli",
     "Saved" : "Tallennettu",
     "Download" : "Lataa",
     "Close" : "Sulje",
@@ -81,6 +84,8 @@ OC.L10N.register(
     "Newest first" : "Uusin ensin",
     "Oldest first" : "Vanhin ensin",
     "Default order" : "Oletusjärjestys",
+    "Enable full text" : "Käytä koko tekstiä",
+    "Disable full text" : "Poista käytöstä koko teksti",
     "Open feed URL" : "Avaa syötteen osoite",
     "Delete" : "Poista",
     "Dismiss" : "Hylkää",
