@@ -13,7 +13,7 @@ namespace OCA\News\Utility;
 
 class Time
 {
-    public function getTime()
+    public function getTime(): int
     {
         return time();
     }
@@ -21,7 +21,7 @@ class Time
     /**
      * @return int the current unix time in miliseconds
      */
-    public function getMicroTime()
+    public function getMicroTime(): int
     {
         list($millisecs, $secs) = explode(" ", microtime());
         return $secs . substr($millisecs, 2, 6);
